/*
 * TpParams.h
 *
 *  Created on: Mar 31, 2025
 *      Author: elphel
 */

#ifndef SRC_TPPARAMS_H_
#define SRC_TPPARAMS_H_
#include <math.h>
class TpParams{
	static constexpr int m_num_cams_lwir =   16;
	static constexpr int m_num_colors_lwir =  1;
	static constexpr int m_num_pairs_lwir = 120;
	static constexpr int m_num_cams_rgb =     4;
	static constexpr int m_num_colors_rgb =   3;
	static constexpr int m_num_pairs_rgb =    6;
	static constexpr unsigned int m_sel_pairs_lwir[4] = {0xffffffff,0xffffffff,0xffffffff,0x00ffffff};
	static constexpr unsigned int m_sel_pairs_rgb[4] =  {0x3f,0,0,0};
	static constexpr int max_num_cams {std::max(m_num_cams_rgb,m_num_cams_lwir)}; // it is always 16 element, RGB uses only first 4
public:
	TpParams(int lwir);
	int     m_lwir;
	float   color_weights[3]{};
	float   generate_RBGA_params[5]{};
    int     num_cams{};
    int     num_colors{};
    int     num_pairs{};
    const unsigned int   * sel_pairs{};
    int     task_size;
    float port_offsets4[4][2] {// used only in textures to scale differences
			{-0.5, -0.5},
			{ 0.5, -0.5},
			{-0.5,  0.5},
			{ 0.5,  0.5}};

    // Could not make it variable port_offsets[?][2], 16 is maximal size

    float port_offsets[max_num_cams][2]; // [NUM_CAMS][2];
    int keep_texture_weights {3}; // 0; // 1; // try with 0 also
    int texture_colors; // 3; // result will be 3+1 RGBA (for mono - 2)
    int kern_tiles;
    int kern_size;
    int corr_size;
//    std::vector<float[2]> m_port_offsets;


private:
    float  m_color_weights_lwir[3] = {
    		1.0f,          // float             weight0,            // scale for R 0.5 / (1.0 + 0.5 +0.2)
			1.0f,          // float             weight1,            // scale for B 0.2 / (1.0 + 0.5 +0.2)
			1.0f};         // float             weight2,            // scale for G 1.0 / (1.0 + 0.5 +0.2)
    float  m_generate_RBGA_params_lwir[5] = {
    		10.0f,         // float             min_shot,           // 10.0
			3.0f,          // float             scale_shot,         // 3.0
			10.0f, // 1.5f,// float             diff_sigma,         // pixel value/pixel change
			10.0f,         // float             diff_threshold,     // pixel value/pixel change
			12.0f}; // 3.0 // float             min_agree,          // minimal number of channels to agree on a point (real number to work with fuzzy averages)
    float m_color_weights_rgb [3] = {
    		0.294118f,     // float             weight0,            // scale for R 0.5 / (1.0 + 0.5 +0.2)
			0.117647f,     // float             weight1,            // scale for B 0.2 / (1.0 + 0.5 +0.2)
			0.588235f};    // float             weight2,            // scale for G 1.0 / (1.0 + 0.5 +0.2)
    float m_generate_RBGA_params_rgb[5] = {
    		10.0f,         // float             min_shot,           // 10.0
			3.0f,          // float             scale_shot,         // 3.0
			1.5f,          // float             diff_sigma,         // pixel value/pixel change
			10.0f,         // float             diff_threshold,     // pixel value/pixel change
			3.0f};         // float             min_agree,          // minimal number of channels to agree on a point (real number to work with fuzzy averages)
};
#endif /* SRC_TPPARAMS_H_ */
